BEGIN
  FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'IDSRC_PUBLICATION_OVERVIEW_V') LOOP
    EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM IDSRC_PUBLICATION_OVERVIEW_V';
  END LOOP;
  FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'IDSRC_PUBLICATION_OVERVIEW_V') LOOP
    EXECUTE IMMEDIATE 'DROP VIEW IDSRC_PUBLICATION_OVERVIEW_V';
  END LOOP;
  FOR k IN (SELECT null FROM all_synonyms WHERE owner = 'PUBLIC' and synonym_name = 'BULK_DATA_V') LOOP
    EXECUTE IMMEDIATE 'DROP PUBLIC SYNONYM BULK_DATA_V';
  END LOOP;
  FOR i IN (SELECT null FROM all_views WHERE owner = user and view_name = 'BULK_DATA_V') LOOP
    EXECUTE IMMEDIATE 'DROP VIEW BULK_DATA_V';
  END LOOP;
END;
/

CREATE VIEW bulk_data_v AS 
  SELECT ds.name source_name,
    dp.id,
    dp.data_producer_type,
    dp.end_time,
    to_char(dp.message) message,
    dp.start_time,
    dp.status,
    afeed.id advisor_feed,
    afeed.source_type,
    afeed.entity_type,
    afeed.name,
    afeed.description,
    afeed.configuration configuration,
    afeed.is_active,
    afeed.is_deleted
   FROM data_production dp
     JOIN advisor_feed_curation afc ON afc.id = dp.id
     JOIN advisor_feed afeed ON afc.advisor_feed = afeed.id
     LEFT JOIN data_source ds ON ds.id = afeed.application
UNION ALL
 SELECT ds.name source_name,
    dp.id,
    dp.data_producer_type,
    dp.end_time,
    to_char(dp.message) message,
    dp.start_time,
    dp.status,
    afeed.id advisor_feed,
    afeed.source_type,
    afeed.entity_type,
    afeed.name,
    afeed.description,
    afeed.configuration configuration,
    afeed.is_active,
    afeed.is_deleted
   FROM data_production dp
     JOIN advisor_feed_generation afg ON afg.id = dp.id
     JOIN advisor_feed afeed ON afg.advisor_feed = afeed.id
     LEFT JOIN data_source ds ON ds.id = afeed.application;

CREATE VIEW idsrc_publication_overview_v AS
  SELECT
    s.timestamp publication_time,
    (SELECT COUNT(id)
      FROM suser
      WHERE effective = 1) unique_ident_count
  FROM snapshot_state ss
    JOIN snapshot s ON s.precursor = ss.current_unification_snapshot;

GRANT SELECT ON igops.bulk_data_v TO ig_report_role;
CREATE PUBLIC SYNONYM bulk_data_v FOR igops.bulk_data_v;

GRANT SELECT ON igops.idsrc_publication_overview_v TO ig_report_role;
CREATE PUBLIC SYNONYM idsrc_publication_overview_v FOR igops.idsrc_publication_overview_v;